==> 0.7.7.tar.gz: lib/src/widgets/message_items/widgets/call_message_item.dart <==
// Copyright 2023, the hatemragab project author.
// All rights reserved. Use of this source code is governed by a
// MIT license that can be found in the LICENSE file.

import 'package:flutter/material.dart';
import 'package:v_chat_message_page/src/theme/theme.dart';
import 'package:v_chat_sdk_core/v_chat_sdk_core.dart';
import 'package:v_chat_utils/v_chat_utils.dart';

class CallMessageItem extends StatelessWidget {
  final VCallMessage message;

  const CallMessageItem({
    Key? key,
    required this.message,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      constraints: const BoxConstraints(
        maxWidth: 300,
      ),
      padding: const EdgeInsets.all(5),
      child: Row(
        mainAxisSize: MainAxisSize.min,
        children: [
          Container(
            padding: const EdgeInsets.all(8),
            decoration:
                const BoxDecoration(shape: BoxShape.circle, color: Colors.red),
            child: Icon(
              message.data.withVideo
                  ? PhosphorIcons.videoCameraFill
                  : PhosphorIcons.phoneCall,
              color: Colors.white,
              size: 30,
            ),
          ),
          Expanded(
            child: ListTile(
              //visualDensity: const VisualDensity(horizontal: 0, vertical: -4),
              dense: true,
              title: message.data.withVideo
                  ? VTrans.labelsOf(context)
                      .videoCall
                      .text
                      .styled(
                        style: message.isMeSender
                            ? context.vMessageThemeNew.textMeSenderColor
                            : context.vMessageThemeNew.textMeReceiverColor,
                      )
                      .size(14)
                  : VTrans.labelsOf(context)
                      .audioCall
                      .text
                      .styled(
                        style: message.isMeSender
                            ? context.vMessageThemeNew.textMeSenderColor
                            : context.vMessageThemeNew.textMeReceiverColor,
                      )
                      .size(14),
              subtitle: _getSub(context),
            ),
          )
        ],
      ),
    );
  }

  Widget _getSub(BuildContext context) {
    if (message.data.duration != null) {
      return "${message.data.duration.toString()} S"
          .text
          .maxLine(2)
          .overflowEllipsis
          .styled(
            style: message.isMeSender
                ? context.vMessageThemeNew.textMeSenderColor
                : context.vMessageThemeNew.textMeReceiverColor,
          )
          .size(14);
    }
    return message.data.callStatus
        .tr(context)
        .toString()
        .text
        .maxLine(2)
        .overflowEllipsis
        .styled(
          style: message.isMeSender
              ? context.vMessageThemeNew.textMeSenderColor
              : context.vMessageThemeNew.textMeReceiverColor,
        )
        .size(14);
  }
}

==> 0.8.0.tar.gz: lib/src/widgets/message_items/widgets/call_message_item.dart <==
// Copyright 2023, the hatemragab project author.
// All rights reserved. Use of this source code is governed by a
// MIT license that can be found in the LICENSE file.

import 'package:flutter/material.dart';
import 'package:v_chat_message_page/src/theme/theme.dart';
import 'package:v_chat_sdk_core/v_chat_sdk_core.dart';
import 'package:v_chat_utils/v_chat_utils.dart';

class CallMessageItem extends StatelessWidget {
  final VCallMessage message;

  const CallMessageItem({
    Key? key,
    required this.message,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      constraints: const BoxConstraints(
        maxWidth: 300,
      ),
      padding: const EdgeInsets.all(5),
      child: Row(
        mainAxisSize: MainAxisSize.min,
        children: [
          Container(
            padding: const EdgeInsets.all(8),
            decoration:
                const BoxDecoration(shape: BoxShape.circle, color: Colors.red),
            child: Icon(
              message.data.withVideo
                  ? PhosphorIcons.videoCameraFill
                  : PhosphorIcons.phoneCall,
              color: Colors.white,
              size: 30,
            ),
          ),
          Expanded(
            child: ListTile(
              //visualDensity: const VisualDensity(horizontal: 0, vertical: -4),
              dense: true,
              title: message.data.withVideo
                  ? VTrans.labelsOf(context)
                      .videoCall
                      .text
                      .styled(
                        style: message.isMeSender
                            ? context.vMessageTheme.senderTextStyle
                            : context.vMessageTheme.receiverTextStyle,
                      )
                      .size(14)
                  : VTrans.labelsOf(context)
                      .audioCall
                      .text
                      .styled(
                        style: message.isMeSender
                            ? context.vMessageTheme.senderTextStyle
                            : context.vMessageTheme.receiverTextStyle,
                      )
                      .size(14),
              subtitle: _getSub(context),
            ),
          )
        ],
      ),
    );
  }

  Widget _getSub(BuildContext context) {
    if (message.data.duration != null) {
      return "${message.data.duration.toString()} S"
          .text
          .maxLine(2)
          .overflowEllipsis
          .styled(
            style: message.isMeSender
                ? context.vMessageTheme.senderTextStyle
                : context.vMessageTheme.receiverTextStyle,
          )
          .size(14);
    }
    return message.data.callStatus
        .tr(context)
        .toString()
        .text
        .maxLine(2)
        .overflowEllipsis
        .styled(
          style: message.isMeSender
              ? context.vMessageTheme.senderTextStyle
              : context.vMessageTheme.receiverTextStyle,
        )
        .size(14);
  }
}
